@@ -7,6 +7,7 @@ import hashlib
 import requests
 import os
 import mimetypes
+import cgi
 
 
 class BaseValidation:
@@ -415,7 +416,7 @@ class none(BaseValidation):
 
 
 class length(BaseValidation):
-    def __init__(self, validations, min=1, max=False, messages={}, raises={}):
+    def __init__(self, validations, min=0, max=False, messages={}, raises={}):
         super().__init__(validations, messages=messages, raises=raises)
         if isinstance(min, str) and ".." in min:
             self.min = int(min.split("..")[0])
@@ -427,8 +428,10 @@ class length(BaseValidation):
     def passes(self, attribute, key, dictionary):
         if not hasattr(attribute, "__len__"):
             attribute = str(attribute)
-
-        return len(attribute) >= self.min and len(attribute) <= self.max
+        if self.max:
+            return len(attribute) >= self.min and len(attribute) <= self.max
+        else:
+            return len(attribute) >= self.min
 
     def message(self, attribute):
         if self.min and not self.max:
@@ -816,6 +819,9 @@ def parse_size(size):
 
 
 class BaseFileValidation(BaseValidation):
+    """This is the abstract base file validation class which is able to handle
+    normal file paths and file objects from masonite file upload requests."""
+
     def __init__(self, validations, messages={}, raises={}):
         super().__init__(validations, messages=messages, raises=raises)
         self.file_check = True
@@ -824,21 +830,48 @@ class BaseFileValidation(BaseValidation):
         self.all_clear = True
 
     def passes(self, attribute, key, dictionary):
-        if not os.path.isfile(attribute):
+        if not self._get_file_if_file(attribute):
             self.file_check = False
             return False
         if self.size:
-            file_size = os.path.getsize(attribute)
+            file_size = self._get_size(attribute)
             if file_size > self.size:
                 self.size_check = False
                 self.all_clear = False
         if self.allowed_extensions:
-            mimetype, encoding = mimetypes.guess_type(attribute)
+            mimetype, encoding = self._get_mimetype(attribute)
             if mimetype not in self.allowed_mimetypes:
                 self.mimes_check = False
                 self.all_clear = False
         return self.all_clear
 
+    def _get_file_if_file(self, data):
+        if isinstance(data, cgi.FieldStorage):
+            return True
+        else:
+            return os.path.isfile(data)
+
+    def _get_size(self, file):
+        if hasattr(file, 'size'):
+            return file.size
+        try:
+            return os.path.getsize(file)
+        except (OSError, TypeError):
+            pass
+        if hasattr(file, 'tell') and hasattr(file, 'seek'):
+            pos = file.tell()
+            file.seek(0, os.SEEK_END)
+            size = file.tell()
+            file.seek(pos)
+            return size
+        raise AttributeError("Unable to determine the file's size.")
+
+    def _get_mimetype(self, file):
+        if isinstance(file, cgi.FieldStorage):
+            return file.type, file.encoding
+        else:
+            return mimetypes.guess_type(file)
+
 
 class file(BaseFileValidation):
     def __init__(self, validations, size=False, mimes=False, messages={}, raises={}):
